@@ -11,7 +11,7 @@ use Getopt::Std;
 use Video::Generator;
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
@@ -41,8 +41,9 @@ sub run {
 
 		print STDERR "Usage: $0 [-d duration] [-f fps] [-h]\n\t".
 			"[-s size] [-v] [--version] output_file\n\n";
-		print STDERR "\t-d duration\tDuration (default value is ".
-			"10000 (=10s)\n";
+		print STDERR "\t-d duration\tDuration in numeric value or ".
+			"with ms/s suffix\n\t\t\t(default value is 10000 ".
+			"[=10s]).\n";
 		print STDERR "\t-f fps\t\tFrame rate\n";
 		print STDERR "\t-h\t\tPrint help.\n";
 		print STDERR "\t-s size\t\tSize (default value is ".
@@ -132,14 +133,16 @@ App::Video::Generator - Perl class for video-generator application.
  # Run.
  App::Video::Generator->new->run;
 
- # Output:
+ # Output like:
  # Usage: /tmp/7b3GEofrss [-d duration] [-f fps] [-h]
- #         [-s size] [--version] output_file
+ #         [-s size] [-v] [--version] output_file
  #
- #         -d duration     Duration (default value is 10000 (=10s)
+ #         -d duration     Duration in numeric value or with ms/s suffix
+ #                         (default value is 10000 [=10s]).
  #         -f fps          Frame rate
  #         -h              Print help.
  #         -s size         Size (default value is 1920x1080).
+ #         -v              Verbose mode.
  #         --version       Print version.
 
 =head1 DEPENDENCIES
@@ -166,6 +169,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
